# Rasp Pi Set Up
import RPi.GPIO as GPIO
import time
GPIO.setmode(GPIO.BCM)

# Declare pin functions on RedBoard
STP1 = 20   # motor moves on this pin rising edge
DIR1 = 21   # DIR pin low = CCW, high CW when open side motor connector faces in
MS11 = 16
MS12 = 12
EN1 =  25   # Low to Enable mtor, High to disable

STP2 = 19   # motor moves on this pin rising edge
DIR2 = 26   # DIR pin low = CCW, high CW when open side motor connector faces in
MS21 = 13
MS22 =  6
EN2 =   5  # Low to Enable mtor, High to disable

# Setup pins
GPIO.setup(STP1, GPIO.OUT)
GPIO.setup(DIR1, GPIO.OUT)
GPIO.setup(MS11, GPIO.OUT)
GPIO.setup(MS12, GPIO.OUT)
GPIO.setup(EN1, GPIO.OUT)

GPIO.setup(STP2, GPIO.OUT)
GPIO.setup(DIR2, GPIO.OUT)
GPIO.setup(MS21, GPIO.OUT)
GPIO.setup(MS22, GPIO.OUT)
GPIO.setup(EN2, GPIO.OUT)

# Declare Constants
stepPeriod = .0005 # time between of motor steps in sec
stepsPerGrid = 200 # number of steps to move one grid square
                   # stepsPerGrid = squareWidth in cm * 40 

# Function to move Gantry horizontally; motors same direction
def horizMove(dir, dist): # dir = -1 means left, +1 means right, dist in number of grid squares
    try:
        # Set directions of both motors to match desired motion
        GPIO.output(DIR1, GPIO.LOW) if dir<0 else GPIO.output(DIR1, GPIO.HIGH)
        GPIO.output(DIR2, GPIO.LOW) if dir<0 else GPIO.output(DIR2, GPIO.HIGH)
        numSteps = stepsPerGrid*dist

        for x in range (0,numSteps):
            GPIO.output(STP1,GPIO.HIGH) #Trigger one step forward
            GPIO.output(STP2,GPIO.HIGH)
            time.sleep(stepPeriod/2)       # /2 b/c only move on rising edge
            GPIO.output(STP1,GPIO.LOW)  #Pull step pin low so it can be triggered again
            GPIO.output(STP2,GPIO.LOW)
            time.sleep(stepPeriod/2)

        print("Returning to Main")
        time.sleep(1)
        main()

    except KeyboardInterrupt:               # If CTRL+C is pressed, exit cleanly:
        GPIO.cleanup()                      # cleanup all GPIO
    finally:                                # force to always clean up on way out
        GPIO.cleanup()                      # cleanup all GPIO


# Function to move Gantry Vertically; motors oppposing directions
def vertMove(dir, dist): # dir = -1 means down, +1 means up, dist in number of grid squares
    try:
        # Set directions of both motors to match desired motion
        GPIO.output(DIR1, GPIO.LOW) if dir<0 else GPIO.output(DIR1, GPIO.HIGH)
        GPIO.output(DIR2, GPIO.HIGH) if dir<0 else GPIO.output(DIR2, GPIO.LOW)
        numSteps = stepsPerGrid*dist

        for x in range (0,numSteps):
            GPIO.output(STP1,GPIO.HIGH)     #Trigger one step forward
            GPIO.output(STP2,GPIO.HIGH)
            time.sleep(stepPeriod/2)        # /2 b/c only move on rising edge
            GPIO.output(STP1,GPIO.LOW)      # Pull step pin low so it can be triggered again
            GPIO.output(STP2,GPIO.LOW)
            time.sleep(stepPeriod/2)
        
        print("Returning to Main")
        time.sleep(1)
        main()

    except KeyboardInterrupt:               # If CTRL+C is pressed, exit cleanly:
        GPIO.cleanup()                      # cleanup all GPIO
    finally:                                # force to always clean up on way out
        GPIO.cleanup()                      # cleanup all GPIO

# main loop, get input on axis, direction, and distance
def main():
    axis = input("Choose Axis: -1 for vertical, +1 for horizontal: ")
    if axis == 1:
        dir = input("Enter direction: -1 for Left, +1 for Right: ")
        dist = input("Enter distance: number of grid squares: ")
        horizMove(dir,dist)
    elif axis == -1:
        dir = input("Enter direction: -1 for Down, +1 for Up: ")
        dist = input("Enter distance: number of grid squares: ")
        vertMove(dir,dist) 
    else:
        print("Invalid input, please try again")
        main()

main()  # ener main loop